@@ -1,7 +1,7 @@
 /**
  * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
  * *
- * Copyright (C) 2011, 2012 Loic J. Duros
+ * Copyright (C) 2011, 2012, 2013, 2014 Loic J. Duros
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -56,7 +56,7 @@ var jsValidTypes = [
 	  /^application\/x-javascript/i
 ];
 
-var stripCDATAOpen = /\<\!\[CDATA\[/gi;
+var stripCDATAOpen = /<\!\[CDATA\[/gi;
 var stripCDATAClose = /]]>/g;
 
 var stripHtmlCommentsInScript = function (s) {
@@ -226,7 +226,7 @@ var domGathererObject = {
 		      if (this.d.hasSrc(this.d.domScripts[i]) &&
 		          !this.d.scriptHasJsWebLabel(this.d.domScripts[i])) {
 
-			      //console.log('an external script', this.d.domScripts[i]);
+			      console.debug('an external script', this.d.domScripts[i]);
 
  			      absolutePath = urlHandler.resolve(this.d.pageURL, this.d.domScripts[i].src);
 			      scriptEntry = scriptObject.Script({'type': scriptTypes.EXTERNAL,
@@ -252,12 +252,12 @@ var domGathererObject = {
 								                                     }), '', true);
 		      }
 
- 		      else if (this.d.domScripts[i].text != '') {
+ 		      else if (this.d.domScripts[i].text !== '') {
  			      // using else if since script text is 
  			      // ignored if src attribute is set.
  			      // adding this.narcissusBugFixLibreJS to fix comment bug.
-			      
- 			      currentScript = stripHtmlCommentsInScript(this.d.domScripts[i].text) + '\n\nthis.narcissusBugFixLibreJS';
+			      var bugfix = require('html_script_finder/bug_fix').narcissusBugFixLibreJS;
+ 			      currentScript = stripHtmlCommentsInScript(this.d.domScripts[i].text + bugfix);
 
 			      scriptEntry = scriptObject.Script({'type': scriptTypes.INLINE,
 							                                 'status': statusTypes.UNCHECKED,
@@ -274,7 +274,7 @@ var domGathererObject = {
 	    }
 	  } catch (e) {
 	    // Any problem arising, we remove the script.
-	    console.log('problem gathering scripts', e, e.lineNumber);
+	    console.debug('problem gathering scripts', e, e.lineNumber);
 	    this.d.removeAllJs();
 	  }
 
@@ -283,7 +283,7 @@ var domGathererObject = {
 
 };
 
-/**
+/*
  * exports.domGatherer
  * Instantiate a brand new clone of the domGatherer.
  * @param dom obj The given dom for analysis.
@@ -298,4 +298,4 @@ exports.domGatherer = function (domHandler) {
   
   return domGatherer;
 
-};
\ No newline at end of file
+};
